@@ -3,16 +3,18 @@
 @author:XuMing(xuming624@qq.com)
 @description: 
 """
-
 import numpy as np
 
-from text2vec.algorithm.distance import cosine_distance
-from text2vec.algorithm.rank_bm25 import BM25Okapi
-from text2vec.utils.logger import get_logger
+from text2vec.utils.rank_bm25 import BM25Okapi
+from text2vec.utils.log import logger
 from text2vec.utils.tokenizer import Tokenizer
-from text2vec.vector import Vector, EmbType
+from text2vec.word2vec import Word2Vec
+from text2vec.sbert import SBert, cos_sim
 
-logger = get_logger(__name__)
+
+class EmbType(object):
+    W2V = 'w2v'
+    SBERT = 'sbert'
 
 
 class SimType(object):
@@ -20,32 +22,30 @@ class SimType(object):
     WMD = 'wmd'
 
 
-class Similarity(Vector):
-    def __init__(self, similarity_type=SimType.COSINE,
-                 embedding_type=EmbType.W2V,
-                 sequence_length=128,
-                 w2v_path='',
-                 w2v_kwargs=None,
-                 bert_model_folder='',
-                 bert_layer_nums=4):
+class Similarity(object):
+    def __init__(self, similarity_type=SimType.COSINE, embedding_type=EmbType.SBERT):
         """
         Cal text similarity
         :param similarity_type:
         :param embedding_type:
-        :param sequence_length:
-        :param w2v_path:
-        :param w2v_kwargs:
-        :param bert_model_folder:
-        :param bert_layer_nums:
         """
-        super(Similarity, self).__init__(embedding_type=embedding_type,
-                                         w2v_path=w2v_path,
-                                         w2v_kwargs=w2v_kwargs,
-                                         sequence_length=sequence_length,
-                                         bert_model_folder=bert_model_folder,
-                                         bert_layer_nums=bert_layer_nums)
+        if similarity_type == SimType.WMD and embedding_type != EmbType.W2V:
+            logger.warning('wmd sim type, emb type must be w2v')
+            embedding_type = EmbType.W2V
+        # logger.debug('embedding type: {}'.format(embedding_type))
         self.similarity_type = similarity_type
-        self.sequence_length = sequence_length
+        self.embedding_type = embedding_type
+        self.tokenizer = Tokenizer()
+        self.model = None
+
+    def load_model(self):
+        if self.model is None:
+            if self.embedding_type == EmbType.W2V:
+                self.model = Word2Vec()
+            elif self.embedding_type == EmbType.SBERT:
+                self.model = SBert()
+            else:
+                raise ValueError('model not found.')
 
     def get_score(self, text1, text2):
         """
@@ -54,18 +54,22 @@ class Similarity(Vector):
         :param text2: str
         :return: float, score
         """
-        ret = 0.0
-        if not text1.strip() or not text2.strip():
-            return ret
-        token_1 = self.tokenize(text1)
-        token_2 = self.tokenize(text2)
+        res = 0.0
+        text1 = text1.strip()
+        text2 = text2.strip()
+        if not text1 or not text2:
+            return res
+        self.load_model()
         if self.similarity_type == SimType.COSINE:
-            emb_1 = self.encode(token_1)
-            emb_2 = self.encode(token_2)
-            ret = cosine_distance(emb_1, emb_2)
+            emb1 = self.model.encode(text1)
+            emb2 = self.model.encode(text2)
+            res = cos_sim(emb1, emb2)[0]
+            res = float(res)
         elif self.similarity_type == SimType.WMD:
-            ret = 1. / (1. + self.model.w2v.wmdistance(token_1, token_2))
-        return ret
+            token1 = self.tokenizer.tokenize(text1)
+            token2 = self.tokenizer.tokenize(text2)
+            res = 1. / (1. + self.model.w2v.wmdistance(token1, token2))
+        return res
 
 
 class SearchSimilarity(object):
